@@ -14,6 +14,9 @@
 #include "CLI.h"
 #include "CommandLine_Parser.h"
 #include "Help.h"
+#include <ZenLib/ZtringList.h>
+#include <ZenLib/Dir.h>
+#include "Common/Policy.h"
 
 #if !defined(WINDOWS)
     #include <unistd.h>
@@ -34,7 +37,7 @@ namespace MediaConch
     //**************************************************************************
 
     //--------------------------------------------------------------------------
-    CLI::CLI() : use_daemon(false), asynchronous(false), force_analyze(false)
+    CLI::CLI() : use_daemon(false), asynchronous(false), force_analyze(false), create_policy_mode(false)
     {
         format = MediaConchLib::format_Text;
     }
@@ -96,7 +99,7 @@ namespace MediaConch
                 return ret; //no more tasks to do
 
             if (ret == CLI_RETURN_FILE)
-                files.push_back(args[pos]); //Append the filename to the list of filenames to parse
+                add_files_recursively(args[pos]);
         }
         return CLI_RETURN_NONE;
     }
@@ -140,6 +143,10 @@ namespace MediaConch
             file_to_report.push_back(files[i]);
         }
 
+        //Ensure to analyze before creating library
+        if (create_policy_mode)
+            return run_create_policy();
+
         //Output
         MediaConchLib::ReportRes result;
         std::vector<std::string> policies_contents;
@@ -156,6 +163,30 @@ namespace MediaConch
         return 0;
     }
 
+    //--------------------------------------------------------------------------
+    int CLI::run_create_policy()
+    {
+        if (files.size() != 1)
+        {
+            error = "Create a policy only with one file";
+            return MediaConchLib::errorHttp_INTERNAL;
+        }
+
+        size_t pos = MCL.create_policy_from_file(files[0]);
+        Policy *p = NULL;
+        std::string policy;
+        if (pos == (size_t)-1 || (p = MCL.get_policy(pos)) == NULL || p->dump_schema(policy) < 0)
+        {
+            error = std::string("Cannot create policy from: ") + files[0];
+            return MediaConchLib::errorHttp_INTERNAL;
+        }
+
+        MediaInfoLib::String policy_mil = ZenLib::Ztring().From_UTF8(policy);
+        STRINGOUT(policy_mil);
+
+        return 0;
+    }
+
     //--------------------------------------------------------------------------
     int CLI::finish()
     {
@@ -270,7 +301,7 @@ namespace MediaConch
         }
         return CLI_RETURN_NONE;
     }
-    
+
     //--------------------------------------------------------------------------
     int CLI::is_ready(size_t i, MediaConchLib::report& report_kind)
     {
@@ -317,6 +348,31 @@ namespace MediaConch
         asynchronous = async;
     }
 
+    //--------------------------------------------------------------------------
+    void CLI::set_create_policy_mode()
+    {
+        create_policy_mode = true;
+    }
+
+    //--------------------------------------------------------------------------
+    void CLI::add_files_recursively(const std::string& filename)
+    {
+        ZenLib::Ztring dirname = ZenLib::Ztring().From_UTF8(filename);
+        if (!ZenLib::Dir::Exists(dirname))
+        {
+            files.push_back(filename);
+            return;
+        }
+
+        ZenLib::ZtringList list = ZenLib::Dir::GetAllFileNames(dirname,
+                                                               (ZenLib::Dir::dirlist_t)(ZenLib::Dir::Include_Files |
+                                                                                        ZenLib::Dir::Include_Hidden |
+                                                                                        ZenLib::Dir::Parse_SubDirs));
+
+        for (size_t i =0; i < list.size(); ++i)
+            files.push_back(ZenLib::Ztring(list[i]).To_UTF8()); //Append the filename to the list of filenames to parse
+    }
+
     //--------------------------------------------------------------------------
     void CLI::print_error(MediaConchLib::errorHttp code)
     {
@@ -331,10 +387,22 @@ namespace MediaConch
             case MediaConchLib::errorHttp_CONNECT:
                 TEXTOUT("Cannot connect to the daemon");
                 break;
+            case MediaConchLib::errorHttp_INTERNAL:
+            {
+                MediaInfoLib::String error_mil = ZenLib::Ztring().From_UTF8(error);
+                STRINGOUT(error_mil);
+                break;
+            }
             default:
                 TEXTOUT("Internal error");
                 break;
         }
     }
 
+    //--------------------------------------------------------------------------
+    int CLI::get_values_for_type_field(const std::string& type, const std::string& field, std::vector<std::string>& values)
+    {
+        return MCL.get_values_for_type_field(type, field, values);
+    }
+
 }
