@@ -25,6 +25,7 @@
 #include "Common/ImplementationReportXsl.h"
 #if defined(_WIN32) || defined(WIN32)
 #include "Common/ImplementationReportDisplayTextXsl.h"
+#include <Shlobj.h>
 #else //defined(_WIN32) || defined(WIN32)
 #include "Common/ImplementationReportDisplayTextUnicodeXsl.h"
 #endif //defined(_WIN32) || defined(WIN32)
@@ -32,6 +33,8 @@
 #include "Common/ImplementationReportMatroskaSchema.h"
 #include "Common/MediaTraceDisplayTextXsl.h"
 #include "Common/MediaTraceDisplayHtmlXsl.h"
+#include "Common/MicroMediaTraceToMediaTraceXsl.h"
+#include "Common/GeneratedCSVVideos.h"
 #include "ZenLib/Ztring.h"
 #include "ZenLib/File.h"
 #include "ZenLib/Dir.h"
@@ -73,7 +76,7 @@ const std::string Core::database_name = "MediaConch.db";
 //---------------------------------------------------------------------------
 Core::Core() : policies(this)
 {
-    MI=new MediaInfoNameSpace::MediaInfoList;
+    MI=new MediaInfoNameSpace::MediaInfo;
 
     config = NULL;
     db = NULL;
@@ -445,16 +448,14 @@ int Core::get_reports_output_JStree(const std::vector<std::string>& files,
         if (report_set[MediaConchLib::report_MediaInfo])
         {
             std::string ret;
-            get_report_saved(vec, MediaConchLib::report_MediaInfo,
-                             MediaConchLib::format_Xml, ret);
+            create_report_mi_xml(vec, ret);
             report += js.format_from_inform_XML(ret);
         }
 
         if (report_set[MediaConchLib::report_MediaTrace])
         {
             std::string ret;
-            get_report_saved(vec, MediaConchLib::report_MediaTrace,
-                         MediaConchLib::format_Xml, ret);
+            create_report_mt_xml(vec, ret);
             report += js.format_from_trace_XML(ret);
         }
     }
@@ -590,7 +591,7 @@ int Core::policies_check(const std::vector<std::string>& files,
 //---------------------------------------------------------------------------
 int Core::transform_with_xslt_file(const std::string& report, const std::string& xslt, std::string& result)
 {
-    Schema *S = new Xslt;
+    Schema *S = new Xslt(!accepts_https());
 
     if (!S->register_schema_from_file(xslt.c_str()))
     {
@@ -614,7 +615,7 @@ int Core::transform_with_xslt_file(const std::string& report, const std::string&
 int Core::transform_with_xslt_memory(const std::string& report, const std::string& memory,
                                      std::string& result)
 {
-    Schema *S = new Xslt;
+    Schema *S = new Xslt(!accepts_https());
 
     if (!S->register_schema_from_memory(memory))
     {
@@ -661,7 +662,7 @@ bool Core::validate_schematron_policy(const std::vector<std::string>& files, int
 {
     std::string policyFile;
     xmlDocPtr doc = NULL;
-    Schema *S = new Schematron;
+    Schema *S = new Schematron(!accepts_https());
     bool valid = true;
 
     if (pos >= 0)
@@ -690,7 +691,7 @@ bool Core::validate_schematron_policy(const std::vector<std::string>& files, int
 bool Core::validate_schematron_policy_from_file(const std::vector<std::string>& files, const std::string& policy, std::string& report)
 {
     bool valid = true;
-    Schema *S = new Schematron;
+    Schema *S = new Schematron(!accepts_https());
 
     if (S->register_schema_from_file(policy.c_str()))
         valid = validation(files, S, report);
@@ -714,7 +715,7 @@ bool Core::validate_schematron_policy_from_file(const std::vector<std::string>&
 bool Core::validate_schematron_policy_from_memory(const std::vector<std::string>& files, const std::string& memory, std::string& report)
 {
     bool valid = true;
-    Schema *S = new Schematron;
+    Schema *S = new Schematron(!accepts_https());
 
     if (S->register_schema_from_memory(memory))
         valid = validation(files, S, report);
@@ -742,7 +743,7 @@ bool Core::validate_xslt_policy(const std::vector<std::string>& files,
     bool valid = true;
     std::string policyFile;
     xmlDocPtr doc = NULL;
-    Schema *S = new Xslt;
+    Schema *S = new Xslt(!accepts_https());
 
     if (pos >= 0)
         doc = policies.create_doc(pos);
@@ -771,7 +772,7 @@ bool Core::validate_xslt_policy_from_file(const std::vector<std::string>& files,
                                           const std::string& policy, std::string& report)
 {
     bool valid = true;
-    Schema *S = new Xslt;
+    Schema *S = new Xslt(!accepts_https());
 
     if (S->register_schema_from_file(policy.c_str()))
         valid = validation(files, S, report);
@@ -798,7 +799,7 @@ bool Core::validate_xslt_policy_from_memory(const std::vector<std::string>& file
                                             bool is_implem)
 {
     bool valid = true;
-    Schema *S = new Xslt;
+    Schema *S = new Xslt(!accepts_https());
 
     if (is_implem)
     {
@@ -835,7 +836,7 @@ bool Core::validate_xslt_policy_from_memory(const std::vector<std::string>& file
 bool Core::validation(const std::vector<std::string>& files, Schema* S, std::string& report)
 {
     std::string xml;
-    create_report_ma_xml(files, S->get_options(), xml, get_bitset_with_mi_mt());
+    create_report_ma_xml(files, S->get_options(), xml, get_bitset_with_mi_mmt());
     bool valid = true;
 
     int ret = S->validate_xml(xml);
@@ -877,6 +878,20 @@ void Core::unify_implementation_options(std::map<std::string, std::string>& opts
         opts["verbosity"] = "\"5\"";
 }
 
+//---------------------------------------------------------------------------
+void Core::unify_no_https(std::string& str)
+{
+    size_t pos;
+    while ((pos = str.find("https://")) != std::string::npos)
+        str.replace(pos + 4, 1, "");
+}
+
+//---------------------------------------------------------------------------
+bool Core::accepts_https()
+{
+    return MI->Option(__T("Https_Get")) != __T("0"); //With test on "0", we handle old version of MediaInfoLib which do not have this option
+}
+
 //***************************************************************************
 // Compression
 //***************************************************************************
@@ -904,6 +919,34 @@ void Core::compress_report(std::string& report, MediaConchLib::compression& comp
     }
 }
 
+//---------------------------------------------------------------------------
+void Core::compress_report_copy(std::string& report, const char* src, size_t src_len, MediaConchLib::compression& compress)
+{
+    switch (compress)
+    {
+        case MediaConchLib::compression_ZLib : 
+        {
+            uLongf dst_len;
+
+            dst_len = (uLongf)src_len;
+            Bytef* dst = new Bytef[src_len + 1];
+
+            if (compress2((Bytef*)dst, &dst_len, (const Bytef*)src, src_len, Z_BEST_COMPRESSION) != Z_OK || src_len <= dst_len)
+            {
+                //Fallback to no compression
+                report = std::string((const char *)src, src_len);
+                compress = MediaConchLib::compression_None;
+            }
+            else
+                report = std::string((const char *)dst, dst_len);
+            delete[] dst;
+        }
+        break;
+        default:
+            report = std::string((const char *)src, src_len);
+    }
+}
+
 //---------------------------------------------------------------------------
 int Core::uncompress_report(std::string& report, MediaConchLib::compression compress)
 {
@@ -970,13 +1013,15 @@ void Core::register_report_xml_to_database(std::string& file, const std::string&
     compress_report(new_report, mode);
 
     db_mutex.Enter();
-    db->save_report(report_kind, MediaConchLib::format_Xml, file, time, new_report, mode);
+    db->save_report(report_kind, MediaConchLib::format_Xml, file, time,
+                    new_report, mode,
+                    true);
     db_mutex.Leave();
 }
 
 //---------------------------------------------------------------------------
 void Core::register_report_mediainfo_text_to_database(std::string& file, const std::string& time,
-                                                      MediaInfoNameSpace::MediaInfoList* curMI)
+                                                      MediaInfoNameSpace::MediaInfo* curMI)
 {
     curMI->Option(__T("Details"), __T("0"));
     curMI->Option(__T("Inform"), String());
@@ -988,13 +1033,14 @@ void Core::register_report_mediainfo_text_to_database(std::string& file, const s
     db_mutex.Enter();
     db->save_report(MediaConchLib::report_MediaInfo, MediaConchLib::format_Text,
                     file, time,
-                    report, mode);
+                    report, mode,
+                    true);
     db_mutex.Leave();
 }
 
 //---------------------------------------------------------------------------
 void Core::register_report_mediainfo_xml_to_database(std::string& file, const std::string& time,
-                                                     MediaInfoNameSpace::MediaInfoList* curMI)
+                                                     MediaInfoNameSpace::MediaInfo* curMI)
 {
     curMI->Option(__T("Details"), __T("0"));
     curMI->Option(__T("Inform"), __T("MIXML"));
@@ -1004,23 +1050,45 @@ void Core::register_report_mediainfo_xml_to_database(std::string& file, const st
     db_mutex.Enter();
     db->save_report(MediaConchLib::report_MediaInfo, MediaConchLib::format_Xml,
                     file, time,
-                    report, mode);
+                    report, mode,
+                    true);
     db_mutex.Leave();
 }
 
 //---------------------------------------------------------------------------
-void Core::register_report_mediatrace_xml_to_database(std::string& file, const std::string& time,
-                                                      MediaInfoNameSpace::MediaInfoList* curMI)
+void Core::register_report_micromediatrace_xml_to_database(std::string& file, const std::string& time,
+                                                      MediaInfoNameSpace::MediaInfo* curMI)
 {
     curMI->Option(__T("Details"), __T("1"));
-    curMI->Option(__T("Inform"), __T("XML"));
-    std::string report = Ztring(curMI->Inform()).To_UTF8();
+    curMI->Option(__T("Inform"), __T("MICRO_XML"));
+
+    //Trying with direct access to the string from MediaInfoLib, then use the classic method if it failed 
+    std::string report;
     MediaConchLib::compression mode = compression_mode;
-    compress_report(report, mode);
+    Ztring Temp = curMI->Option(__T("File_Details_StringPointer"), Ztring());
+    if (Temp.find_first_not_of(__T("0123456789:")) == string::npos) //Form is "Pointer:Size"
+    {
+        ZtringList TempZL;
+        TempZL.Separator_Set(0, __T(":"));
+        TempZL.Write(Temp);
+        if (TempZL.size() == 2)
+        {
+            const char* report_buffer = (const char*)TempZL[0].To_int64u();
+            size_t report_size = (size_t)TempZL[1].To_int64u();
+            compress_report_copy(report, report_buffer, report_size, mode);
+        }
+    }
+    if (report.empty())
+    {
+        std::string report = Ztring(curMI->Inform()).To_UTF8();
+        compress_report(report, mode);
+    }
+
     db_mutex.Enter();
-    db->save_report(MediaConchLib::report_MediaTrace, MediaConchLib::format_Xml,
+    db->save_report(MediaConchLib::report_MicroMediaTrace, MediaConchLib::format_Xml,
                     file, time,
-                    report, mode);
+                    report, mode,
+                    true);
     db_mutex.Leave();
 }
 
@@ -1051,7 +1119,7 @@ void Core::get_content_of_media_in_xml(std::string& report)
 
 //---------------------------------------------------------------------------
 void Core::register_file_to_database(std::string& filename, const std::string& report,
-                                     MediaConchLib::report report_kind, MediaInfoNameSpace::MediaInfoList* curMI)
+                                     MediaConchLib::report report_kind, MediaInfoNameSpace::MediaInfo* curMI)
 {
     const std::string& time = get_last_modification_file(filename);
 
@@ -1063,7 +1131,7 @@ void Core::register_file_to_database(std::string& filename, const std::string& r
 }
 
 //---------------------------------------------------------------------------
-void Core::register_file_to_database(std::string& filename, MediaInfoNameSpace::MediaInfoList* curMI)
+void Core::register_file_to_database(std::string& filename, MediaInfoNameSpace::MediaInfo* curMI)
 {
     const std::string& time = get_last_modification_file(filename);
 
@@ -1071,8 +1139,8 @@ void Core::register_file_to_database(std::string& filename, MediaInfoNameSpace::
     register_report_mediainfo_text_to_database(filename, time, curMI);
     register_report_mediainfo_xml_to_database(filename, time, curMI);
 
-    // MediaTrace
-    register_report_mediatrace_xml_to_database(filename, time, curMI);
+    // MicroMediaTrace
+    register_report_micromediatrace_xml_to_database(filename, time, curMI);
 }
 
 //---------------------------------------------------------------------------
@@ -1084,18 +1152,14 @@ void Core::register_file_to_database(std::string& filename)
     register_report_mediainfo_text_to_database(filename, time, MI);
     register_report_mediainfo_xml_to_database(filename, time, MI);
 
-    // MediaTrace
-    register_report_mediatrace_xml_to_database(filename, time, MI);
+    // MicroMediaTrace
+    register_report_micromediatrace_xml_to_database(filename, time, MI);
 }
 
 //---------------------------------------------------------------------------
 void Core::create_report_mi_xml(const std::vector<std::string>& files, std::string& report)
 {
-    if (files.size() == 1)
-    {
-        get_report_saved(files, MediaConchLib::report_MediaInfo, MediaConchLib::format_Xml, report);
-        return;
-    }
+    bool AcceptsHttps = accepts_https();
 
     std::string version = ZenLib::Ztring(Menu_Option_Preferences_Option (__T("Info_Version"), __T(""))).To_UTF8();
     std::string search(" - v");
@@ -1106,14 +1170,14 @@ void Core::create_report_mi_xml(const std::vector<std::string>& files, std::stri
     std::stringstream start;
     start << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
     start << "<MediaInfo\n";
-    start << "xmlns=\"https://mediaarea.net/mediainfo\"\n";
+    start << "xmlns=\"http" << (AcceptsHttps ? "s" : string()) << "://mediaarea.net/mediainfo\"\n";
     start << "xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\"\n";
-    start << "xsi:schemaLocation=\"https://mediaarea.net/mediaarea https://mediaarea.net/mediainfo/mediainfo_2_0.xsd\"\n";
+    start << "xsi:schemaLocation=\"http" << (AcceptsHttps ? "s" : string()) << "://mediaarea.net/mediaarea http" << (AcceptsHttps ? "s" : string()) << "://mediaarea.net/mediainfo/mediainfo_2_0.xsd\"\n";
     start << "version=\"2.0beta1\">\n";
     start << "<!-- Work in progress, not for production -->\n";
     start << "<creatingLibrary version=\"";
     start << version;
-    start << "\" url=\"https://mediaarea.net/MediaInfo\">MediaInfoLib</creatingLibrary>\n";
+    start << "\" url=\"http" << (AcceptsHttps ? "s" : string()) << "://mediaarea.net/MediaInfo\">MediaInfoLib</creatingLibrary>\n";
     report += start.str();
     std::vector<std::string> vec;
     for (size_t i = 0; i < files.size(); ++i)
@@ -1135,12 +1199,7 @@ void Core::create_report_mi_xml(const std::vector<std::string>& files, std::stri
 //---------------------------------------------------------------------------
 void Core::create_report_mt_xml(const std::vector<std::string>& files, std::string& report)
 {
-    if (files.size() == 1)
-    {
-        get_report_saved(files, MediaConchLib::report_MediaTrace, MediaConchLib::format_Xml, report);
-        return;
-    }
-
+    bool AcceptsHttps = accepts_https();
     std::string version = ZenLib::Ztring(Menu_Option_Preferences_Option (__T("Info_Version"), __T(""))).To_UTF8();
     std::string search(" - v");
     size_t pos = version.find(search);
@@ -1150,13 +1209,14 @@ void Core::create_report_mt_xml(const std::vector<std::string>& files, std::stri
     std::stringstream start;
     start << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
     start << "<MediaTrace\n";
-    start << "xmlns=\"https://mediaarea.net/mediatrace\"\n";
+    start << "xmlns=\"http" << (AcceptsHttps ? "s" : string()) << "://mediaarea.net/mediatrace\"\n";
     start << "xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\"\n";
-    start << "xsi:schemaLocation=\"https://mediaarea.net/mediaarea https://mediaarea.net/mediatrace/mediatrace_0_1.xsd\"\n";
+    start << "xsi:schemaLocation=\"http" << (AcceptsHttps ? "s" : string()) << "://mediaarea.net/mediaarea http" << (AcceptsHttps ? "s" : string()) << "://mediaarea.net/mediatrace/mediatrace_0_1.xsd\"\n";
     start << "version=\"0.1\">\n";
     start << "<creatingLibrary version=\"";
     start << version;
-    start << "\" url=\"https://mediaarea.net/MediaInfo\">MediaInfoLib</creatingLibrary>\n";
+    start << "\" url=\"http" << (AcceptsHttps ? "s" : string()) << "://mediaarea.net/MediaInfo\">MediaInfoLib</creatingLibrary>\n";
+
     report += start.str();
 
     std::vector<std::string> vec;
@@ -1164,24 +1224,73 @@ void Core::create_report_mt_xml(const std::vector<std::string>& files, std::stri
     {
         vec.clear();
         vec.push_back(files[i]);
-        report += "<media ref=\"" + files[i] + "\">\n";
+        std::string file(files[i]);
+        xml_escape_attributes(file);
+        report += "<media ref=\"" + file + "\">\n";
 
-        std::string info;
-        get_report_saved(vec, MediaConchLib::report_MediaTrace, MediaConchLib::format_Xml, info);
-        get_content_of_media_in_xml(info);
-        if (info.length())
-            report += info;
+        std::string tmp;
+        create_report_mmt_xml(vec, tmp);
+        if (tmp.length())
+        {
+            std::string memory(micromediatrace_to_mediatrace_xsl);
+            transform_with_xslt_memory(tmp, memory, tmp);
+            get_content_of_media_in_xml(tmp);
+            report += tmp;
+        }
         report += std::string("</media>\n");
     }
     report += std::string("</MediaTrace>");
 }
 
+//---------------------------------------------------------------------------
+void Core::create_report_mmt_xml(const std::vector<std::string>& files, std::string& report)
+{
+    bool AcceptsHttps = accepts_https();
+    std::string version = ZenLib::Ztring(Menu_Option_Preferences_Option (__T("Info_Version"), __T(""))).To_UTF8();
+    std::string search(" - v");
+    size_t pos = version.find(search);
+    if (pos != std::string::npos)
+        version = version.substr(pos + search.length());
+
+    std::stringstream start;
+    start << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
+    start << "<MicroMediaTrace";
+    start << " xmlns=\"http" << (AcceptsHttps ? "s" : string()) << "://mediaarea.net/micromediatrace\"";
+    start << " xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\"";
+    start << " mtsl=\"http" << (AcceptsHttps ? "s" : string()) << "://mediaarea.net/micromediatrace https://mediaarea.net/micromediatrace/micromediatrace.xsd\"";
+    start << " version=\"0.1\">";
+    start << "<creatingLibrary version=\"";
+    start << version;
+    start << "\" url=\"http" << (AcceptsHttps ? "s" : string()) << "://mediaarea.net/MediaInfo\">MediaInfoLib</creatingLibrary>";
+
+    report += start.str();
+
+    std::vector<std::string> vec;
+    for (size_t i = 0; i < files.size(); ++i)
+    {
+        vec.clear();
+        vec.push_back(files[i]);
+        std::string file(files[i]);
+        xml_escape_attributes(file);
+        report += "<media ref=\"" + file + "\">";
+
+        std::string trace;
+        get_report_saved(vec, MediaConchLib::report_MicroMediaTrace, MediaConchLib::format_Xml, trace);
+        if (trace.length())
+            report += trace;
+        report += std::string("</media>");
+    }
+    report += std::string("</MicroMediaTrace>");
+}
+
 //---------------------------------------------------------------------------
 void Core::create_report_ma_xml(const std::vector<std::string>& files,
                                 const std::map<std::string, std::string>& options,
                                 std::string& report,
                                 std::bitset<MediaConchLib::report_Max> reports)
 {
+    bool AcceptsHttps = accepts_https();
+
     std::string version = ZenLib::Ztring(Menu_Option_Preferences_Option (__T("Info_Version"), __T(""))).To_UTF8();
     std::string search(" - v");
     size_t pos = version.find(search);
@@ -1191,14 +1300,14 @@ void Core::create_report_ma_xml(const std::vector<std::string>& files,
     std::stringstream start;
     start << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
     start << "<MediaArea\n";
-    start << "xmlns=\"https://mediaarea.net/mediaarea\"\n";
+    start << "xmlns=\"http" << (AcceptsHttps ? "s" : string()) << "://mediaarea.net/mediaarea\"\n";
     start << "xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\"\n";
-    start << "xsi:schemaLocation=\"https://mediaarea.net/mediaarea https://mediaarea.net/mediaarea/mediaarea_0_1.xsd\"\n";
+    start << "xsi:schemaLocation=\"http" << (AcceptsHttps ? "s" : string()) << "://mediaarea.net/mediaarea http" << (AcceptsHttps ? "s" : string()) << "://mediaarea.net/mediaarea/mediaarea_0_1.xsd\"\n";
     start << "version=\"0.1\">\n";
     start << "<!-- Work in progress, not for production -->\n";
     start << "<creatingLibrary version=\"";
     start << version;
-    start << "\" url=\"https://mediaarea.net/MediaInfo\">MediaInfoLib</creatingLibrary>\n";
+    start << "\" url=\"http" << (AcceptsHttps ? "s" : string()) << "://mediaarea.net/MediaInfo\">MediaInfoLib</creatingLibrary>\n";
     report += start.str();
 
     std::vector<std::string> vec;
@@ -1206,7 +1315,9 @@ void Core::create_report_ma_xml(const std::vector<std::string>& files,
     {
         vec.clear();
         vec.push_back(files[i]);
-        report += "<media ref=\"" + files[i] + "\">\n";
+        std::string file(files[i]);
+        xml_escape_attributes(file);
+        report += "<media ref=\"" + file + "\">\n";
 
         if (reports[MediaConchLib::report_MediaInfo])
         {
@@ -1214,18 +1325,30 @@ void Core::create_report_ma_xml(const std::vector<std::string>& files,
             get_report_saved(vec, MediaConchLib::report_MediaInfo, MediaConchLib::format_Xml, info);
             get_content_of_media_in_xml(info);
             if (info.length())
-                report += "<MediaInfo xmlns=\"https://mediaarea.net/mediainfo\" version=\"2.0beta1\">" + info + "</MediaInfo>\n";
+                report += "<MediaInfo xmlns=\"http" + (AcceptsHttps ? "s" : string()) + "://mediaarea.net/mediainfo\" version=\"2.0beta1\">" + info + "</MediaInfo>\n";
         }
 
         if (reports[MediaConchLib::report_MediaTrace])
         {
-        std::string trace;
-        get_report_saved(vec, MediaConchLib::report_MediaTrace,
-                         MediaConchLib::format_Xml, trace);
-        get_content_of_media_in_xml(trace);
-        if (trace.length())
-            report += "<MediaTrace xmlns=\"https://mediaarea.net/mediatrace\" version=\"0.1\">"
-                + trace + "</MediaTrace>\n";
+            std::string trace;
+            create_report_mt_xml(vec, trace);
+            get_content_of_media_in_xml(trace);
+            report += "<MediaTrace xmlns=\"http" + (AcceptsHttps ? "s" : string()) + "://mediaarea.net/mediatrace\" version=\"0.1\">\n";
+            if (trace.length())
+                report += trace;
+            report += "</MediaTrace>\n";
+        }
+
+        if (reports[MediaConchLib::report_MicroMediaTrace])
+        {
+            std::string trace;
+            get_report_saved(vec, MediaConchLib::report_MicroMediaTrace,
+                             MediaConchLib::format_Xml, trace);
+            report += "<MicroMediaTrace xmlns=\"http" + (AcceptsHttps ? "s" : string()) + "://mediaarea.net/micromediatrace\" version=\"0.1\">\n";
+            if (trace.length())
+                report += trace;
+
+            report += "</MicroMediaTrace>\n";
         }
 
         if (reports[MediaConchLib::report_MediaConch])
@@ -1236,7 +1359,7 @@ void Core::create_report_ma_xml(const std::vector<std::string>& files,
             else
                 implem = std::string();
 
-            report += "<MediaConch xmlns=\"https://mediaarea.net/mediaconch\" version=\"0.1\">"
+            report += "<MediaConch xmlns=\"http" + (AcceptsHttps ? "s" : string()) + "://mediaarea.net/mediaconch\" version=\"0.2\">\n"
                 + implem + "</MediaConch>\n";
         }
         report += std::string("</media>\n");
@@ -1278,7 +1401,7 @@ void Core::get_report_saved(const std::vector<std::string>& files,
         return;
     }
 
-    if (reportKind != MediaConchLib::report_MediaInfo && reportKind != MediaConchLib::report_MediaTrace
+    if (reportKind != MediaConchLib::report_MediaInfo && reportKind != MediaConchLib::report_MicroMediaTrace
         && reportKind != MediaConchLib::report_MediaVeraPdf && reportKind != MediaConchLib::report_MediaDpfManager)
         return;
 
@@ -1454,6 +1577,9 @@ bool Core::file_is_registered_in_db(const std::string& filename)
         }
     }
 
+    if (res)
+        res = db->has_version_registered(filename);
+
     db_mutex.Leave();
     return res;
 }
@@ -1480,16 +1606,24 @@ std::string Core::get_local_config_path()
 {
     std::string local_path(".");
 #if defined(WINDOWS)
-    char username[UNLEN+1];
-    DWORD username_len = UNLEN+1;
-    GetUserNameA(username, &username_len);
+    PWSTR path = NULL;
 
-    std::string wuser(username, username_len-1);
-    std::string user_name(wuser.begin(), wuser.end());
-    std::stringstream path;
+    if (SHGetKnownFolderPath(FOLDERID_RoamingAppData, KF_FLAG_CREATE, NULL, &path) == S_OK)
+    {
+        local_path = Ztring(path).To_UTF8();
+        local_path += "/MediaConch/";
+        CoTaskMemFree(path);
 
-    path << "C:/Users/" << user_name << "/AppData/Roaming/MediaConch/";
-    local_path = path.str();
+        for (;;)
+        {
+            size_t pos = 0;
+            pos = local_path.find('\\');
+            if (pos == std::string::npos)
+                break;
+
+            local_path[pos] = '/';
+        }
+    }
 #elif defined(UNIX)
     const char* home = NULL;
 
@@ -1501,17 +1635,19 @@ std::string Core::get_local_config_path()
         else
             home = ".";
     }
-    local_path = std::string(home) + Path_Separator + std::string(".config/");
+    local_path = std::string(home) + std::string("/.config/");
 #elif defined(MACOS) || defined(MACOSX)
-    const char* user = NULL;
+    const char* home = NULL;
 
-    if ((user = getenv("USER")) == NULL)
+    if ((home = getenv("HOME")) == NULL)
     {
         struct passwd *pw = getpwuid(getuid());
         if (pw)
-            user = pw->pw_name;
+            home = pw->pw_dir;
+        else
+            home = ".";
     }
-    local_path = std::string("/Users/") + user + std::string("/Library/Preferences/");
+    local_path = std::string(home) + std::string("/Library/Preferences/");
 #endif
 
     Ztring z_path = ZenLib::Ztring().From_UTF8(local_path);
@@ -1526,16 +1662,24 @@ std::string Core::get_local_data_path()
 {
     std::string local_path(".");
 #if defined(WINDOWS)
-    char username[UNLEN+1];
-    DWORD username_len = UNLEN+1;
-    GetUserNameA(username, &username_len);
+    PWSTR path = NULL;
 
-    std::string wuser(username, username_len-1);
-    std::string user_name(wuser.begin(), wuser.end());
-    std::stringstream path;
+    if (SHGetKnownFolderPath(FOLDERID_RoamingAppData, KF_FLAG_CREATE, NULL, &path) == S_OK)
+    {
+        local_path = Ztring(path).To_UTF8();
+        local_path += "/MediaConch/";
+	CoTaskMemFree(path);
 
-    path << "C:/Users/" << user_name << "/AppData/Roaming/MediaConch/";
-    local_path = path.str();
+	for (;;)
+	{
+	    size_t pos = 0;
+	    pos = local_path.find('\\');
+	    if (pos == std::string::npos)
+	      break;
+
+	    local_path[pos] = '/';
+	}
+    }
 #elif defined(UNIX)
     const char* home;
 
@@ -1547,17 +1691,19 @@ std::string Core::get_local_data_path()
         else
             home = ".";
     }
-    local_path = std::string(home) + Path_Separator + std::string(".local/share/MediaConch/");
+    local_path = std::string(home) + std::string("/.local/share/MediaConch/");
 #elif defined(MACOS) || defined(MACOSX)
-    const char* user = NULL;
+    const char* home;
 
-    if ((user = getenv("USER")) == NULL)
+    if ((home = getenv("HOME")) == NULL)
     {
         struct passwd *pw = getpwuid(getuid());
         if (pw)
-            user = pw->pw_name;
+            home = pw->pw_dir;
+        else
+            home = ".";
     }
-    local_path = std::string("/Users/") + user + std::string("/Library/Application Support/MediaConch/");
+    local_path = std::string(home) + std::string("/Library/Application Support/MediaConch/");
 #endif
 
     Ztring z_path = ZenLib::Ztring().From_UTF8(local_path);
@@ -1645,6 +1791,45 @@ void Core::WaitRunIsFinished()
     }
 }
 
+//---------------------------------------------------------------------------
+void Core::xml_escape_attributes(std::string& xml)
+{
+    size_t len = xml.length();
+    for (size_t i = 0; i < len; ++i)
+    {
+        switch(xml[i])
+        {
+            case '&':
+                xml.replace(i, 1, "&amp;");
+                len += 4;
+                i += 4;
+                break;
+            case '<':
+                xml.replace(i, 1, "&lt;");
+                len += 3;
+                i += 3;
+                break;
+            case '>':
+                xml.replace(i, 1, "&lg;");
+                len += 3;
+                i += 3;
+                break;
+            case '\'':
+                xml.replace(i, 1, "&apos;");
+                len += 5;
+                i += 5;
+                break;
+            case '"':
+                xml.replace(i, 1, "&quot;");
+                len += 5;
+                i += 5;
+                break;
+            default:
+                break;
+        }
+    }
+}
+
 //---------------------------------------------------------------------------
 std::bitset<MediaConchLib::report_Max> Core::get_bitset_with_mi_mt()
 {
@@ -1655,6 +1840,16 @@ std::bitset<MediaConchLib::report_Max> Core::get_bitset_with_mi_mt()
     return bits;
 }
 
+//---------------------------------------------------------------------------
+std::bitset<MediaConchLib::report_Max> Core::get_bitset_with_mi_mmt()
+{
+    std::bitset<MediaConchLib::report_Max> bits;
+
+    bits.set(MediaConchLib::report_MediaInfo);
+    bits.set(MediaConchLib::report_MicroMediaTrace);
+    return bits;
+}
+
 //---------------------------------------------------------------------------
 bool Core::is_using_daemon() const
 {
@@ -1700,4 +1895,38 @@ bool Core::dpfmanager_report_is_valid(const std::string& report)
     return true;
 }
 
+//---------------------------------------------------------------------------
+int Core::get_fields_for_type(const std::string& type, std::vector<std::string>& fields)
+{
+    const std::map<std::string, std::list<std::string> >& types = Policies::existing_type;
+
+    if (types.find(type) == types.end())
+        return -1;
+
+    const std::list<std::string>& list = types.at(type);
+    std::list<std::string>::const_iterator it = list.begin();
+    for (; it != list.end(); ++it)
+        fields.push_back(*it);
+    return 0;
+}
+
+//---------------------------------------------------------------------------
+int Core::get_values_for_type_field(const std::string& type, const std::string& field, std::vector<std::string>& values)
+{
+    std::map<std::string, std::map<std::string, std::vector<std::string> > > vs;
+    if (get_generated_values_from_csv(vs) < 0)
+        return -1;
+
+    if (vs.find(type) != vs.end())
+    {
+        if (vs[type].find(field) != vs[type].end())
+        {
+            for (size_t i = 0; i < vs[type][field].size(); ++i)
+                values.push_back(vs[type][field][i]);
+        }
+    }
+
+    return 0;
+}
+
 }
