@@ -47,6 +47,12 @@ public:
     // file_from_id
     int file_from_id(int id, std::string& filename);
 
+    // default_values_for_type
+    int default_values_for_type(const std::string& type, std::vector<std::string>& values);
+
+    // create_policy_from_file
+    int create_policy_from_file(const std::string& id, std::string& policy);
+
     // Analyze
     int analyze(const std::string& file, bool& registered, bool force_analyze);
 
