@@ -46,6 +46,11 @@ MediaConchLib::MediaConchLib(bool no_daemon) : use_daemon(false), force_no_daemo
 MediaConchLib::~MediaConchLib()
 {
     delete core;
+    if (daemon_client)
+    {
+        delete daemon_client;
+        daemon_client = NULL;
+    }
 }
 
 //***************************************************************************
@@ -79,6 +84,7 @@ int MediaConchLib::close()
     if (daemon_client)
     {
         daemon_client->close();
+        delete daemon_client;
         daemon_client = NULL;
     }
     return 0;
@@ -118,6 +124,12 @@ bool MediaConchLib::ReportAndFormatCombination_IsValid(const std::vector<std::st
                                                        const std::string& display, MediaConchLib::format& Format,
                                                        std::string& reason)
 {
+    if (reports[MediaConchLib::report_MicroMediaTrace])
+    {
+        reason = "MicroMediaTrace is for internal use only";
+        return false;
+    }
+
     // Forcing some formats
     if (Format == MediaConchLib::format_Text && !display.empty())
         Format = format_Xml; //Forcing Text (default) to XML
@@ -130,7 +142,7 @@ bool MediaConchLib::ReportAndFormatCombination_IsValid(const std::vector<std::st
 
     if (reports.count() > 1 && Format == MediaConchLib::format_Xml)
         Format = MediaConchLib::format_MaXml;
-    
+
     // Test of incompatibilities
     if (reports[MediaConchLib::report_MediaConch] && reports[MediaConchLib::report_MediaTrace]
         && Format == MediaConchLib::format_Text)
@@ -165,9 +177,10 @@ int MediaConchLib::analyze(const std::string& file, bool& registered, bool force
     if (!file.length())
         return errorHttp_INVALID_DATA;
 
+    // Send Options by API
     if (use_daemon)
         return daemon_client->analyze(file, registered, force_analyze);
-    return core->open_file(file, registered, force_analyze);
+    return core->open_file(file, registered, Options, force_analyze);
 }
 
 //---------------------------------------------------------------------------
@@ -395,22 +408,71 @@ int MediaConchLib::get_ui_database_path(std::string& path) const
 //***************************************************************************
 
 //---------------------------------------------------------------------------
-void MediaConchLib::save_policies()
+size_t MediaConchLib::create_policy_from_file(const std::string& file)
 {
-    for (size_t i = 0; i < core->policies.policies.size(); ++i)
-        if (!core->policies.policies[i]->saved)
-            core->policies.export_schema(NULL, i);
+    if (use_daemon)
+    {
+        std::string policy;
+        if (daemon_client->create_policy_from_file(file, policy) < 0)
+            return (size_t)-1;
+
+        size_t pos = core->policies.policies.size();
+        if (core->policies.import_policy_from_memory(file.c_str(), policy.c_str(), policy.length(), false))
+            return (size_t)-1;
+        return pos;
+    }
+    return core->policies.create_policy_from_file(file);
 }
 
 //---------------------------------------------------------------------------
-void MediaConchLib::save_policy(size_t pos, const std::string* filename)
+int MediaConchLib::create_xslt_policy(std::string& err)
 {
-    if (pos > core->policies.policies.size())
-        return;
-    const char* path = NULL;
-    if (filename)
-        path = filename->c_str();
-    core->policies.export_schema(path, pos);
+    return core->policies.create_xslt_policy(err);
+}
+
+//---------------------------------------------------------------------------
+int MediaConchLib::duplicate_policy(int id, std::string& err)
+{
+    return core->policies.duplicate_policy(id, err);
+}
+
+//---------------------------------------------------------------------------
+int MediaConchLib::policy_change_name(int id, const std::string& name, const std::string& description, std::string& err)
+{
+    return core->policies.policy_change_name(id, name, description, err);
+}
+
+//---------------------------------------------------------------------------
+int MediaConchLib::create_policy_rule(int policy_id, std::string& err)
+{
+    return core->policies.create_policy_rule(policy_id, err);
+}
+
+//---------------------------------------------------------------------------
+int MediaConchLib::edit_policy_rule(int policy_id, int rule_id, const XsltRule *rule, std::string& err)
+{
+    return core->policies.edit_policy_rule(policy_id, rule_id, rule, err);
+}
+
+//---------------------------------------------------------------------------
+int MediaConchLib::duplicate_policy_rule(int policy_id, int rule_id, std::string& err)
+{
+    return core->policies.duplicate_policy_rule(policy_id, rule_id, err);
+}
+
+//---------------------------------------------------------------------------
+int MediaConchLib::delete_policy_rule(int policy_id, int rule_id, std::string& err)
+{
+    return core->policies.delete_policy_rule(policy_id, rule_id, err);
+}
+
+//---------------------------------------------------------------------------
+void MediaConchLib::save_policies()
+{
+    std::string err;
+    for (size_t i = 0; i < core->policies.policies.size(); ++i)
+        if (!core->policies.policies[i]->saved)
+            core->policies.export_policy(NULL, i, err);
 }
 
 //---------------------------------------------------------------------------
@@ -433,16 +495,16 @@ bool MediaConchLib::is_policy_saved(size_t pos) const
 //---------------------------------------------------------------------------
 int MediaConchLib::import_policy_from_file(const std::string& filename, std::string& err)
 {
-    int ret = core->policies.import_schema(filename);
+    int ret = core->policies.import_policy(filename);
     if (ret < 0)
         err = core->policies.get_error();
     return ret;
 }
 
 //---------------------------------------------------------------------------
-int MediaConchLib::import_policy_from_memory(const std::string& memory, const std::string& filename, std::string& err)
+int MediaConchLib::import_policy_from_memory(const char* filename, const std::string& memory, std::string& err, bool is_system_policy)
 {
-    int ret = core->policies.import_schema_from_memory(filename, memory.c_str(), memory.length());
+    int ret = core->policies.import_policy_from_memory(filename, memory.c_str(), memory.length(), is_system_policy);
     if (ret < 0)
         err = core->policies.get_error();
     return ret;
@@ -463,7 +525,7 @@ size_t MediaConchLib::get_policies_count() const
 //---------------------------------------------------------------------------
 Policy* MediaConchLib::get_policy(size_t pos)
 {
-    if (pos >= core->policies.policies.size())
+    if ((int)pos < 0 || pos >= core->policies.policies.size())
         return NULL;
     return core->policies.policies[pos];
 }
@@ -474,6 +536,12 @@ const std::vector<Policy *>& MediaConchLib::get_policies() const
     return core->policies.policies;
 }
 
+//---------------------------------------------------------------------------
+int MediaConchLib::save_policy(size_t pos, std::string& err)
+{
+    return core->policies.save_policy(pos, err);
+}
+
 //---------------------------------------------------------------------------
 void MediaConchLib::add_policy(Policy* p)
 {
@@ -481,9 +549,15 @@ void MediaConchLib::add_policy(Policy* p)
 }
 
 //---------------------------------------------------------------------------
-void MediaConchLib::remove_policy(size_t pos)
+int MediaConchLib::remove_policy(size_t pos, std::string& err)
 {
-    core->policies.erase_policy(pos);
+    return core->policies.erase_policy(pos, err);
+}
+
+//---------------------------------------------------------------------------
+int MediaConchLib::export_policy(const char* filename, size_t pos, std::string& err)
+{
+    return core->policies.export_policy(filename, pos, err);
 }
 
 //---------------------------------------------------------------------------
@@ -516,4 +590,16 @@ void MediaConchLib::get_daemon_address(std::string& addr, int& port) const
     core->get_daemon_address(addr, port);
 }
 
+//---------------------------------------------------------------------------
+int MediaConchLib::get_values_for_type_field(const std::string& type, const std::string& field, std::vector<std::string>& values)
+{
+    return core->get_values_for_type_field(type, field, values);
+}
+
+//---------------------------------------------------------------------------
+int MediaConchLib::get_fields_for_type(const std::string& type, std::vector<std::string>& fields)
+{
+    return core->get_fields_for_type(type, fields);
+}
+
 }
