@@ -75,7 +75,7 @@ public:
         return std::string();
     }
 
-    Report string_to_Report(std::string str)
+    Report string_to_Report(const std::string& str)
     {
 #define ReportString(report)       \
         if (!str.compare(#report)) \
@@ -101,6 +101,7 @@ public:
 
         switch (r)
         {
+            ReasonString(NO_REASON);
             ReasonString(FILE_NOT_EXISTING);
             ReasonString(ID_NOT_EXISTING);
             ReasonString(NOT_READY);
@@ -111,12 +112,13 @@ public:
         return std::string();
     }
 
-    Reason string_to_Reason(std::string str)
+    Reason string_to_Reason(const std::string& str)
     {
 #define ReasonString(reason)       \
         if (!str.compare(#reason)) \
             return reason;
 
+        ReasonString(NO_REASON);
         ReasonString(FILE_NOT_EXISTING);
         ReasonString(ID_NOT_EXISTING);
         ReasonString(NOT_READY);
@@ -346,60 +348,104 @@ public:
         std::string  to_str() const;
     };
 
+    struct Default_Values_For_Type_Req
+    {
+        std::string  type;
+        std::string  field;
+        std::string  to_str() const;
+    };
+
+    struct Default_Values_For_Type_Res
+    {
+        std::vector<std::string> values;
+        std::string              to_str() const;
+    };
+
+    struct Create_Policy_From_File_Req
+    {
+        int                          id;
+        std::string                  to_str() const;
+    };
+
+    struct Create_Policy_From_File_Nok
+    {
+        int                          id;
+        Reason                       error;
+        std::string                  to_str() const;
+    };
+
+    struct Create_Policy_From_File_Res
+    {
+        Create_Policy_From_File_Res() :  nok(NULL) {}
+        std::string                      policy;
+        Create_Policy_From_File_Nok     *nok;
+        std::string                      to_str() const;
+    };
+
 public:
     //Constructor/Destructor
     RESTAPI();
     virtual ~RESTAPI();
 
     // Serialize: Request
-    std::string serialize_analyze_req(Analyze_Req& req);
-    std::string serialize_status_req(Status_Req& req);
-    std::string serialize_report_req(Report_Req& req);
-    std::string serialize_retry_req(Retry_Req& req);
-    std::string serialize_clear_req(Clear_Req& req);
-    std::string serialize_list_req(List_Req& req);
-    std::string serialize_validate_req(Validate_Req& req);
-    std::string serialize_file_from_id_req(File_From_Id_Req& req);
+    int serialize_analyze_req(Analyze_Req& req, std::string&);
+    int serialize_status_req(Status_Req& req, std::string&);
+    int serialize_report_req(Report_Req& req, std::string&);
+    int serialize_retry_req(Retry_Req& req, std::string&);
+    int serialize_clear_req(Clear_Req& req, std::string&);
+    int serialize_list_req(List_Req& req, std::string&);
+    int serialize_validate_req(Validate_Req& req, std::string&);
+    int serialize_file_from_id_req(File_From_Id_Req& req, std::string&);
+    int serialize_default_values_for_type_req(Default_Values_For_Type_Req& req, std::string&);
+    int serialize_create_policy_from_file_req(Create_Policy_From_File_Req& req, std::string&);
 
     // Serialize: Result
-    std::string serialize_analyze_res(Analyze_Res& res);
-    std::string serialize_status_res(Status_Res& res);
-    std::string serialize_report_res(Report_Res& res);
-    std::string serialize_retry_res(Retry_Res& res);
-    std::string serialize_clear_res(Clear_Res& res);
-    std::string serialize_list_res(List_Res& res);
-    std::string serialize_validate_res(Validate_Res& res);
-    std::string serialize_file_from_id_res(File_From_Id_Res& res);
+    int serialize_analyze_res(Analyze_Res& res, std::string&);
+    int serialize_status_res(Status_Res& res, std::string&);
+    int serialize_report_res(Report_Res& res, std::string&);
+    int serialize_retry_res(Retry_Res& res, std::string&);
+    int serialize_clear_res(Clear_Res& res, std::string&);
+    int serialize_list_res(List_Res& res, std::string&);
+    int serialize_validate_res(Validate_Res& res, std::string&);
+    int serialize_file_from_id_res(File_From_Id_Res& res, std::string&);
+    int serialize_default_values_for_type_res(Default_Values_For_Type_Res& res, std::string&);
+    int serialize_create_policy_from_file_res(Create_Policy_From_File_Res& res, std::string&);
 
     // Parse: Request
-    Analyze_Req      *parse_analyze_req(std::string data);
-    Status_Req       *parse_status_req(std::string data);
-    Report_Req       *parse_report_req(std::string data);
-    Retry_Req        *parse_retry_req(std::string data);
-    Clear_Req        *parse_clear_req(std::string data);
-    List_Req         *parse_list_req(std::string data);
-    Validate_Req     *parse_validate_req(std::string data);
-    File_From_Id_Req *parse_file_from_id_req(std::string data);
+    Analyze_Req                 *parse_analyze_req(const std::string& data);
+    Status_Req                  *parse_status_req(const std::string& data);
+    Report_Req                  *parse_report_req(const std::string& data);
+    Retry_Req                   *parse_retry_req(const std::string& data);
+    Clear_Req                   *parse_clear_req(const std::string& data);
+    List_Req                    *parse_list_req(const std::string& data);
+    Validate_Req                *parse_validate_req(const std::string& data);
+    File_From_Id_Req            *parse_file_from_id_req(const std::string& data);
+    Default_Values_For_Type_Req *parse_default_values_for_type_req(const std::string& data);
+    Create_Policy_From_File_Req *parse_create_policy_from_file_req(const std::string& data);
 
     // Parse: URI Request
-    Analyze_Req      *parse_uri_analyze_req(const std::string& uri);
-    Status_Req       *parse_uri_status_req(const std::string& uri);
-    Report_Req       *parse_uri_report_req(const std::string& uri);
-    Retry_Req        *parse_uri_retry_req(const std::string& uri);
-    Clear_Req        *parse_uri_clear_req(const std::string& uri);
-    List_Req         *parse_uri_list_req(const std::string& uri);
-    Validate_Req     *parse_uri_validate_req(const std::string& uri);
-    File_From_Id_Req *parse_uri_file_from_id_req(const std::string& uri);
+    Analyze_Req                 *parse_uri_analyze_req(const std::string& uri);
+    Status_Req                  *parse_uri_status_req(const std::string& uri);
+    Report_Req                  *parse_uri_report_req(const std::string& uri);
+    Retry_Req                   *parse_uri_retry_req(const std::string& uri);
+    Clear_Req                   *parse_uri_clear_req(const std::string& uri);
+    List_Req                    *parse_uri_list_req(const std::string& uri);
+    Validate_Req                *parse_uri_validate_req(const std::string& uri);
+    File_From_Id_Req            *parse_uri_file_from_id_req(const std::string& uri);
+    Default_Values_For_Type_Req *parse_uri_default_values_for_type_req(const std::string& uri);
+    Create_Policy_From_File_Req *parse_uri_create_policy_from_file_req(const std::string& uri);
 
     // Parse: Request
-    Analyze_Res      *parse_analyze_res(std::string data);
-    Status_Res       *parse_status_res(std::string data);
-    Report_Res       *parse_report_res(std::string data);
-    Retry_Res        *parse_retry_res(std::string data);
-    Clear_Res        *parse_clear_res(std::string data);
-    List_Res         *parse_list_res(std::string data);
-    Validate_Res     *parse_validate_res(std::string data);
-    File_From_Id_Res *parse_file_from_id_res(std::string data);
+    Analyze_Res                 *parse_analyze_res(const std::string& data);
+    Status_Res                  *parse_status_res(const std::string& data);
+    Report_Res                  *parse_report_res(const std::string& data);
+    Retry_Res                   *parse_retry_res(const std::string& data);
+    Clear_Res                   *parse_clear_res(const std::string& data);
+    List_Res                    *parse_list_res(const std::string& data);
+    Validate_Res                *parse_validate_res(const std::string& data);
+    File_From_Id_Res            *parse_file_from_id_res(const std::string& data);
+    Default_Values_For_Type_Res *parse_default_values_for_type_res(const std::string& data);
+    Create_Policy_From_File_Res *parse_create_policy_from_file_res(const std::string& data);
 
     std::string get_error() const { return error; }
 
