@@ -49,14 +49,15 @@ namespace MediaConch {
         }
         working.clear();
         CS.Leave();
+        delete queue;
     }
 
     //---------------------------------------------------------------------------
-    int Scheduler::add_element_to_queue(const std::string& filename)
+    int Scheduler::add_element_to_queue(const std::string& filename, const std::vector<std::string>& options)
     {
         static int index = 0;
 
-        queue->add_element(PRIORITY_NONE, index++, filename);
+        queue->add_element(PRIORITY_NONE, index++, filename, options);
         run_element();
         return index - 1;
     }
@@ -82,7 +83,7 @@ namespace MediaConch {
         CS.Leave();
     }
 
-    void Scheduler::work_finished(QueueElement *el, MediaInfoNameSpace::MediaInfoList* MI)
+    void Scheduler::work_finished(QueueElement *el, MediaInfoNameSpace::MediaInfo* MI)
     {
         if (!el)
             return;
@@ -129,9 +130,7 @@ namespace MediaConch {
                 break;
         if (it != working.end())
         {
-            //TODO: get percent without blocking
-            //percent_done = it->first->percent_done();
-            percent_done = 50.0;
+            percent_done = it->first->percent_done();
             CS.Leave();
             return false;
         }
@@ -160,10 +159,10 @@ namespace MediaConch {
         return ret;
     }
 
-    int Scheduler::another_work_to_do(QueueElement *el, MediaInfoNameSpace::MediaInfoList* MI)
+    int Scheduler::another_work_to_do(QueueElement *el, MediaInfoNameSpace::MediaInfo* MI)
     {
         // Before registering, check the format
-        String format = MI->Get(0, Stream_General, 0, __T("Format"));
+        String format = MI->Get(Stream_General, 0, __T("Format"));
         std::string format_str = ZenLib::Ztring(format).To_UTF8().c_str();
 
         std::map<std::string, Plugin*> plugins = core->get_format_plugins();
