@@ -28,9 +28,14 @@ namespace MediaConch {
 
 //---------------------------------------------------------------------------
 XsltRule::XsltRule(const XsltRule& r)
+{
+    *this = r;
+}
+
+XsltRule& XsltRule::operator=(const XsltRule& r)
 {
     if (&r == this)
-        return;
+        return *this;
 
     this->title = r.title;
     this->ope = r.ope;
@@ -40,6 +45,7 @@ XsltRule::XsltRule(const XsltRule& r)
     this->occurrence = r.occurrence;
     this->value = r.value;
     this->test = r.test;
+    return *this;
 }
 
 //***************************************************************************
@@ -530,7 +536,7 @@ int XsltPolicy::find_policychecks_node(xmlNodePtr node)
         }
         else
             ret = 0;
-        
+
         child = child->next;
     }
     return ret;
@@ -671,7 +677,7 @@ bool XsltPolicy::validate_template_match_node(xmlNodePtr node)
 int XsltPolicy::find_template_match_node(xmlNodePtr node)
 {
     xmlChar *match = xmlGetNoNsProp(node, (const unsigned char*)"match");
-    
+
     if (match == NULL || std::string((const char*)match) != "ma:MediaArea")
         return 1;
 
@@ -735,7 +741,7 @@ int XsltPolicy::find_template_node(xmlNodePtr node)
 }
 
 //---------------------------------------------------------------------------
-int XsltPolicy::import_schema_from_doc(const std::string& filename, xmlDocPtr doc)
+int XsltPolicy::import_schema_from_doc(xmlDocPtr doc, const std::string& filename)
 {
     if (!doc)
     {
@@ -806,12 +812,17 @@ xmlNsPtr XsltPolicy::create_namespace_xsl(xmlNodePtr node)
 //---------------------------------------------------------------------------
 xmlNsPtr XsltPolicy::create_namespace_mc(xmlNodePtr node)
 {
+    if (no_https)
+        return xmlNewNs(node, (const xmlChar*)"http://mediaarea.net/mediaconch", NULL);
     return xmlNewNs(node, (const xmlChar*)"https://mediaarea.net/mediaconch", NULL);
 }
 
 //---------------------------------------------------------------------------
 xmlNsPtr XsltPolicy::create_namespace_ma(xmlNodePtr node)
 {
+    if (no_https)
+        return xmlNewNs(node, (const xmlChar*)"http://mediaarea.net/mediaarea",
+                        (const xmlChar *)"ma");
     return xmlNewNs(node, (const xmlChar*)"https://mediaarea.net/mediaarea",
                     (const xmlChar *)"ma");
 }
@@ -819,6 +830,9 @@ xmlNsPtr XsltPolicy::create_namespace_ma(xmlNodePtr node)
 //---------------------------------------------------------------------------
 xmlNsPtr XsltPolicy::create_namespace_mi(xmlNodePtr node)
 {
+    if (no_https)
+        return xmlNewNs(node, (const xmlChar*)"http://mediaarea.net/mediainfo",
+                        (const xmlChar *)"mi");
     return xmlNewNs(node, (const xmlChar*)"https://mediaarea.net/mediainfo",
                     (const xmlChar *)"mi");
 }
@@ -867,7 +881,7 @@ bool XsltPolicy::parse_test_for_rule_free_text(const std::string& test, XsltRule
 {
     rule->use_free_text = true;
     rule->test = test;
-    return true;
+    return false;
 }
 
 //---------------------------------------------------------------------------
@@ -1464,7 +1478,7 @@ void XsltPolicy::write_check_context_child(xmlNodePtr node, XsltRule *rule)
     xmlNodePtr child = xmlNewNode(NULL, (const xmlChar *)"context");
     child->ns = node->ns;
     xmlAddChild(node, child);
-    
+
     write_check_context_field_child(child, rule);
     if (operator_need_value(rule->ope))
         write_check_context_value_child(child, rule);
@@ -1721,4 +1735,111 @@ int XsltPolicy::get_operator_pretty_name(const std::string& ope, std::string& pr
     return -1;
 }
 
+//---------------------------------------------------------------------------
+int XsltPolicy::create_rule_from_media_track_child(xmlNodePtr node, const std::string& type)
+{
+    for (xmlNodePtr child = node->children; child; child = child->next)
+    {
+        if (child->type != XML_ELEMENT_NODE || !child->name)
+            continue;
+
+        std::string name((const char*)child->name);
+        if (name == "FileSize"
+         || name == "Duration"
+         || name == "DURATION"
+         || name == "OverallBitRate"
+         || name == "FrameCount"
+         || name == "StreamSize"
+         || name == "BitRate"
+         || name == "FrameCount"
+         || name == "Delay"
+         || name == "extra")
+            continue;
+
+        XsltRule *rule = new XsltRule;
+
+        rule->type = type;
+        rule->field = (const char*)child->name;
+        rule->ope = "is_equal";
+        rule->occurrence = -1;
+        rule->value = (const char*)xmlNodeGetContent(child);
+        rule->title = rule->type + "/" + rule->field + " is " + rule->value;
+        rules.push_back(rule);
+    }
+    return 0;
+}
+
+//---------------------------------------------------------------------------
+int XsltPolicy::find_media_track_node(xmlNodePtr node, std::string& type)
+{
+    xmlChar *property = xmlGetNoNsProp(node, (const unsigned char*)"type");
+
+    if (property == NULL)
+        return -1;
+
+    type = std::string((const char*)property);
+    return 0;
+}
+
+//---------------------------------------------------------------------------
+int XsltPolicy::find_media_track_node(xmlNodePtr node)
+{
+    for (xmlNodePtr child = node->children; child; child = child->next)
+    {
+        std::string def("track");
+        if (!child->name || def.compare((const char*)child->name))
+            continue;
+
+        std::string type;
+        if (find_media_track_node(child, type) < 0)
+            return -1;
+
+        if (create_rule_from_media_track_child(child, type) < 0)
+            return -1;
+    }
+    return 0;
+}
+
+//---------------------------------------------------------------------------
+int XsltPolicy::create_policy_from_mi(const std::string& report)
+{
+    Xslt s(no_https);
+    xmlSetGenericErrorFunc(&s, &s.manage_generic_error);
+
+    xmlDocPtr doc = xmlParseMemory(report.c_str(), report.length());
+    xmlSetGenericErrorFunc(NULL, NULL);
+
+    if (!doc)
+    {
+        // maybe put the errors from s.errors
+        error = "The MediaInfo report given cannot be parsed";
+        return -1;
+    }
+
+    xmlNodePtr root = xmlDocGetRootElement(doc);
+    if (!root)
+    {
+        error = "No root node, leaving";
+        xmlFreeDoc(doc);
+        return 0;
+    }
+
+    for (xmlNodePtr child = root->children; child; child = child->next)
+    {
+        std::string def("media");
+        if (!child->name || def.compare((const char*)child->name))
+            continue;
+
+        if (find_media_track_node(child) < 0)
+        {
+            xmlFreeDoc(doc);
+            return -1;
+        }
+        break;
+    }
+
+    xmlFreeDoc(doc);
+    return 0;
+}
+
 }
