@@ -55,6 +55,7 @@ namespace MediaConch
         int parse_version(const std::string& argument);
         int parse_fork(const std::string& argument);
         int parse_configuration(const std::string& argument);
+        int parse_plugins_configuration(const std::string& argument);
         int parse_compression(const std::string& argument);
         int parse_implementationschema(const std::string& argument);
         int parse_implementationverbosity(const std::string& argument);
@@ -72,9 +73,20 @@ namespace MediaConch
                                     RESTAPI::Retry_Res& res, void *arg);
         static int on_clear_command(const RESTAPI::Clear_Req* req,
                                     RESTAPI::Clear_Res& res, void *arg);
+        static int on_list_command(const RESTAPI::List_Req* req,
+                                   RESTAPI::List_Res& res, void *arg);
+        static int on_validate_command(const RESTAPI::Validate_Req* req,
+                                       RESTAPI::Validate_Res& res, void *arg);
+        static int on_file_from_id_command(const RESTAPI::File_From_Id_Req* req,
+                                           RESTAPI::File_From_Id_Res& res, void *arg);
+        static int on_default_values_for_type_command(const RESTAPI::Default_Values_For_Type_Req* req,
+                                                      RESTAPI::Default_Values_For_Type_Res& res, void *arg);
+        static int on_create_policy_from_file_command(const RESTAPI::Create_Policy_From_File_Req* req,
+                                                      RESTAPI::Create_Policy_From_File_Res& res, void *arg);
 
         size_t get_first_free_slot();
         bool id_is_existing(int id) const;
+        bool file_is_registered(const std::string& file, size_t& id);
         std::string get_date() const;
 
         std::vector<std::string*> current_files;
