@@ -147,4 +147,27 @@ void DatabaseUi::get_sql_query_for_update_ui_settings_table_v7(std::string& q)
     q = create.str();
 }
 
+//---------------------------------------------------------------------------
+void DatabaseUi::get_sql_query_for_update_ui_settings_table_v8(std::string& q)
+{
+    std::stringstream create;
+    create << "ALTER TABLE UI_SETTINGS"; // Table name
+    create << " ADD DEFAULT_SAVE_POLICY_PATH TEXT DEFAULT NULL;";
+    create << "ALTER TABLE UI_SETTINGS"; // Table name
+    create << " ADD DEFAULT_SAVE_DISPLAY_PATH TEXT DEFAULT NULL;";
+    create << "ALTER TABLE UI_SETTINGS"; // Table name
+    create << " ADD LAST_SAVE_POLICY_PATH TEXT DEFAULT NULL;";
+    create << "ALTER TABLE UI_SETTINGS"; // Table name
+    create << " ADD LAST_SAVE_DISPLAY_PATH TEXT DEFAULT NULL;";
+    create << "ALTER TABLE UI_SETTINGS"; // Table name
+    create << " ADD DEFAULT_LOAD_POLICY_PATH TEXT DEFAULT NULL;";
+    create << "ALTER TABLE UI_SETTINGS"; // Table name
+    create << " ADD DEFAULT_LOAD_DISPLAY_PATH TEXT DEFAULT NULL;";
+    create << "ALTER TABLE UI_SETTINGS"; // Table name
+    create << " ADD LAST_LOAD_POLICY_PATH TEXT DEFAULT NULL;";
+    create << "ALTER TABLE UI_SETTINGS"; // Table name
+    create << " ADD LAST_LOAD_DISPLAY_PATH TEXT DEFAULT NULL;";
+    q = create.str();
+}
+
 }
