@@ -9,12 +9,6 @@
 #include "mainwindow.h"
 #include "checkerwindow.h"
 #include "ui_mainwindow.h"
-#include "policiestree.h"
-#include "policiesmenu.h"
-#include "policymenu.h"
-#include "groupofrules.h"
-#include "rulemenu.h"
-#include "ruleedit.h"
 #include "WebPage.h"
 #include "WebView.h"
 #include "progressbar.h"
@@ -121,9 +115,13 @@ void CheckerWindow::create_web_view_finished(bool ok)
     is_finished = true;
 
     result_table = new ResultTable(mainwindow, (WebPage*)main_view->page());
-    for (size_t i = 0; i < files.size(); ++i)
-        result_table->add_file_to_result_table(files[i]);
-    files.clear();
+    if (files.size())
+    {
+        for (size_t i = 0; i < files.size(); ++i)
+            result_table->add_file_to_result_table(files[i]);
+        files.clear();
+        page_start_waiting_loop();
+    }
 
     if (progress_bar)
     {
@@ -132,6 +130,8 @@ void CheckerWindow::create_web_view_finished(bool ok)
         progress_bar = NULL;
     }
 
+    main_view->show();
+    main_view->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
     mainwindow->set_widget_to_layout(main_view);
 }
 
@@ -140,6 +140,7 @@ void CheckerWindow::set_web_view_content(QString& html)
 {
     if (!main_view)
         main_view = new WebView(mainwindow);
+    main_view->hide();
 
     WebPage* page = new WebPage(mainwindow, main_view);
     main_view->setPage(page);
@@ -155,8 +156,11 @@ void CheckerWindow::set_web_view_content(QString& html)
     QWebChannel *channel = new QWebChannel(page);
     page->setWebChannel(channel);
     channel->registerObject("webpage", page);
+    main_view->setHtml(html.toUtf8(), url);
 #endif
+#if defined(WEB_MACHINE_KIT)
     main_view->setContent(html.toUtf8(), "text/html", url);
+#endif
 }
 
 //---------------------------------------------------------------------------
@@ -187,7 +191,7 @@ void CheckerWindow::create_web_view()
 }
 
 //---------------------------------------------------------------------------
-void CheckerWindow::change_local_files(QStringList& files)
+void CheckerWindow::change_local_files(const QStringList& files)
 {
     if (!main_view || !main_view->page())
         return;
@@ -574,24 +578,17 @@ void CheckerWindow::change_result_in_template(const QString& result, QString& ht
 //---------------------------------------------------------------------------
 void CheckerWindow::change_body_script_in_template(QString& html)
 {
-    QRegExp reg("\\{% block bodyScript %\\}\\{% endblock %\\}");
+    QRegExp reg("\\{\\{ QT_SCRIPTS \\}\\}");
     QString script;
     int     pos = 0;
 
     reg.setMinimal(true);
 #if defined(WEB_MACHINE_KIT)
-    script = "";
+    script = "        <script type=\"text/javascript\" src=\"qrc:/checker.js\"></script>\n";
 #elif defined(WEB_MACHINE_ENGINE)
-    script = "<script>\n"
-        "var webpage;\n"
-        "$(document).ready(function()\n"
-        "{\n"
-        "// Register Qt WebPage object\n"
-        "new QWebChannel(qt.webChannelTransport, function (channel) {\n"
-        "webpage = channel.objects.webpage;\n"
-        "});\n"
-        "});\n"
-        "</script>";
+    script = "        <script type=\"text/javascript\" src=\"qrc:/qtwebchannel/qwebchannel.js\"></script>\n"
+             "        <script type=\"text/javascript\" src=\"qrc:/webengine.js\"></script>\n"
+             "        <script type=\"text/javascript\" src=\"qrc:/checker.js\"></script>\n";
 #endif
     if ((pos = reg.indexIn(html, pos)) != -1)
         html.replace(pos, reg.matchedLength(), script);
@@ -654,4 +651,16 @@ void CheckerWindow::add_file_to_result_table(const std::string& full_path)
     result_table->add_file_to_result_table(full_path);
 }
 
+void CheckerWindow::page_start_waiting_loop()
+{
+    if (!main_view || !is_finished)
+        return;
+
+    WebPage* page = (WebPage*)main_view->page();
+    if (!page)
+        return;
+
+    page->use_javascript("startWaitingLoop()");
+}
+
 }
